@@ -1,4 +1,5 @@
-# last modified 25 March 2011 by J. Fox
+# last modified 2011-09-28 by J. Fox
+#  applied patch to improve window behaviour supplied by Milan Bouchet-Valat 2011-09-22
 
 # Data menu dialogs
 
@@ -10,12 +11,12 @@ newDataSet <- function() {
 		dsnameValue <- trim.blanks(tclvalue(dsname))
 		if (dsnameValue == "") {
 			errorCondition(recall=newDataSet,
-				message=gettextRcmdr("You must enter the name of a data set."))
+					message=gettextRcmdr("You must enter the name of a data set."))
 			return()
 		}
 		if (!is.valid.name(dsnameValue)) {
 			errorCondition(recall=newDataSet,
-				message=paste('"', dsnameValue, '" ', gettextRcmdr("is not a valid name."), sep=""))
+					message=paste('"', dsnameValue, '" ', gettextRcmdr("is not a valid name."), sep=""))
 			return()
 		}
 		if (is.element(dsnameValue, listDataSets())) {
@@ -24,6 +25,7 @@ newDataSet <- function() {
 				return()
 			}
 		}
+		closeDialog()
 		command <- "edit(as.data.frame(NULL))"
 		result <- justDoIt(command)
 		result <- as.data.frame(lapply(result, function(x) if (is.character(x)) factor(x) else x))
@@ -37,7 +39,6 @@ newDataSet <- function() {
 			}
 			activeDataSet(dsnameValue)
 		}
-		closeDialog()
 		tkfocus(CommanderWindow())
 	}
 	OKCancelHelp(helpSubject="edit.data.frame")
@@ -816,7 +817,7 @@ importRODBCtable <- function(){
 		}
 		File <- tclvalue(tkgetOpenFile(filetypes = gettextRcmdr(
 					'{"All Files" {"*"}} {"MS Access database" {".mdb" ".MDB"}} {"MS Access 2007 database" {".accdb" ".ACCDB"}} {"dBase-like file" {".dbf" ".DBF"}} {"MS Excel 2007 file" {".xlsx" ".XLSX"}} {"MS Excel file" {".xls" ".XLS"}}'
-				)))
+				), parent=CommanderWindow()))
 		if(File == ""){
 			tkfocus(CommanderWindow())
 			return()
@@ -1269,7 +1270,9 @@ exportDataSet <- function() {
 			else if (delim == "commas") ","
 			else trim.blanks(tclvalue(otherVariable))
 		saveFile <- tclvalue(tkgetSaveFile(filetypes=gettextRcmdr('{"All Files" {"*"}} {"Text Files" {".txt" ".TXT" ".dat" ".DAT" ".csv" ".CSV"}}'),
-				defaultextension="txt", initialfile=paste(dsname, ".txt", sep="")))
+				defaultextension="txt",
+                                initialfile=paste(dsname, ".txt", sep=""),
+                                parent=CommanderWindow()))
 		if (saveFile == "") {
 			tkfocus(CommanderWindow())
 			return()
